==> ejc-salary-impl-3.0.0-20241129.064655-72-sources.jar: com/ejianc/business/salary/bean/SocialSecurityChangeSdetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 社保公积金调整-社保明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_social_security_change_sdetail")
public class SocialSecurityChangeSdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="payment_base")
    private BigDecimal paymentBase; // 缴费基数
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="person_annuity_money_percent")
    private BigDecimal personAnnuityMoneyPercent; // 个人养老金比例
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="company_annuity_money_percent")
    private BigDecimal companyAnnuityMoneyPercent; // 公司养老金比例
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="person_medical_money_percent")
    private BigDecimal personMedicalMoneyPercent; // 个人医疗金额比例
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="company_medical_money_percent")
    private BigDecimal companyMedicalMoneyPercent; // 公司医疗金额比例
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="person_unemployment_money_percent")
    private BigDecimal personUnemploymentMoneyPercent; // 个人失业金额比例
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_unemployment_money_percent")
    private BigDecimal companyUnemploymentMoneyPercent; // 公司失业金额比例
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_childbirth_money_percent")
    private BigDecimal companyChildbirthMoneyPercent; // 公司生育金额比例
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="company_injury_money_percent")
    private BigDecimal companyInjuryMoneyPercent; // 公司工伤金额比例
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="pid")
    private Long pid; // 主表id
    
    
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getPersonAnnuityMoneyPercent() {
        return personAnnuityMoneyPercent;
    }

    public void setPersonAnnuityMoneyPercent(BigDecimal personAnnuityMoneyPercent) {
        this.personAnnuityMoneyPercent = personAnnuityMoneyPercent;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoneyPercent() {
        return companyAnnuityMoneyPercent;
    }

    public void setCompanyAnnuityMoneyPercent(BigDecimal companyAnnuityMoneyPercent) {
        this.companyAnnuityMoneyPercent = companyAnnuityMoneyPercent;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getPersonMedicalMoneyPercent() {
        return personMedicalMoneyPercent;
    }

    public void setPersonMedicalMoneyPercent(BigDecimal personMedicalMoneyPercent) {
        this.personMedicalMoneyPercent = personMedicalMoneyPercent;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoneyPercent() {
        return companyMedicalMoneyPercent;
    }

    public void setCompanyMedicalMoneyPercent(BigDecimal companyMedicalMoneyPercent) {
        this.companyMedicalMoneyPercent = companyMedicalMoneyPercent;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getPersonUnemploymentMoneyPercent() {
        return personUnemploymentMoneyPercent;
    }

    public void setPersonUnemploymentMoneyPercent(BigDecimal personUnemploymentMoneyPercent) {
        this.personUnemploymentMoneyPercent = personUnemploymentMoneyPercent;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoneyPercent() {
        return companyUnemploymentMoneyPercent;
    }

    public void setCompanyUnemploymentMoneyPercent(BigDecimal companyUnemploymentMoneyPercent) {
        this.companyUnemploymentMoneyPercent = companyUnemploymentMoneyPercent;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyChildbirthMoneyPercent() {
        return companyChildbirthMoneyPercent;
    }

    public void setCompanyChildbirthMoneyPercent(BigDecimal companyChildbirthMoneyPercent) {
        this.companyChildbirthMoneyPercent = companyChildbirthMoneyPercent;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public BigDecimal getCompanyInjuryMoneyPercent() {
        return companyInjuryMoneyPercent;
    }

    public void setCompanyInjuryMoneyPercent(BigDecimal companyInjuryMoneyPercent) {
        this.companyInjuryMoneyPercent = companyInjuryMoneyPercent;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-salary-impl-3.0.0-20250912.043458-184-sources.jar: com/ejianc/business/salary/bean/SocialSecurityChangeSdetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 社保公积金调整-社保明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_social_security_change_sdetail")
public class SocialSecurityChangeSdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="user_id")
    private Long userId; // 员工id
    @TableField(value="user_code")
    private String userCode; // 员工编号
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="payment_base")
    private BigDecimal paymentBase; // 缴费基数
    @TableField(value="person_annuity_money")
    private BigDecimal personAnnuityMoney; // 个人养老金
    @TableField(value="person_annuity_money_percent")
    private BigDecimal personAnnuityMoneyPercent; // 个人养老金比例
    @TableField(value="company_annuity_money")
    private BigDecimal companyAnnuityMoney; // 公司养老金
    @TableField(value="company_annuity_money_percent")
    private BigDecimal companyAnnuityMoneyPercent; // 公司养老金比例
    @TableField(value="person_medical_money")
    private BigDecimal personMedicalMoney; // 个人医疗金额
    @TableField(value="person_medical_money_percent")
    private BigDecimal personMedicalMoneyPercent; // 个人医疗金额比例
    @TableField(value="company_medical_money")
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    @TableField(value="company_medical_money_percent")
    private BigDecimal companyMedicalMoneyPercent; // 公司医疗金额比例
    @TableField(value="person_unemployment_money")
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    @TableField(value="person_unemployment_money_percent")
    private BigDecimal personUnemploymentMoneyPercent; // 个人失业金额比例
    @TableField(value="company_unemployment_money")
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    @TableField(value="company_unemployment_money_percent")
    private BigDecimal companyUnemploymentMoneyPercent; // 公司失业金额比例
    @TableField(value="company_childbirth_money")
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    @TableField(value="company_childbirth_money_percent")
    private BigDecimal companyChildbirthMoneyPercent; // 公司生育金额比例
    @TableField(value="company_injury_money")
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    @TableField(value="company_injury_money_percent")
    private BigDecimal companyInjuryMoneyPercent; // 公司工伤金额比例
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="critical_illness_mny")
    private BigDecimal criticalIllnessMny; // 大病医保


    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getPersonAnnuityMoneyPercent() {
        return personAnnuityMoneyPercent;
    }

    public void setPersonAnnuityMoneyPercent(BigDecimal personAnnuityMoneyPercent) {
        this.personAnnuityMoneyPercent = personAnnuityMoneyPercent;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoneyPercent() {
        return companyAnnuityMoneyPercent;
    }

    public void setCompanyAnnuityMoneyPercent(BigDecimal companyAnnuityMoneyPercent) {
        this.companyAnnuityMoneyPercent = companyAnnuityMoneyPercent;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getPersonMedicalMoneyPercent() {
        return personMedicalMoneyPercent;
    }

    public void setPersonMedicalMoneyPercent(BigDecimal personMedicalMoneyPercent) {
        this.personMedicalMoneyPercent = personMedicalMoneyPercent;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoneyPercent() {
        return companyMedicalMoneyPercent;
    }

    public void setCompanyMedicalMoneyPercent(BigDecimal companyMedicalMoneyPercent) {
        this.companyMedicalMoneyPercent = companyMedicalMoneyPercent;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getPersonUnemploymentMoneyPercent() {
        return personUnemploymentMoneyPercent;
    }

    public void setPersonUnemploymentMoneyPercent(BigDecimal personUnemploymentMoneyPercent) {
        this.personUnemploymentMoneyPercent = personUnemploymentMoneyPercent;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoneyPercent() {
        return companyUnemploymentMoneyPercent;
    }

    public void setCompanyUnemploymentMoneyPercent(BigDecimal companyUnemploymentMoneyPercent) {
        this.companyUnemploymentMoneyPercent = companyUnemploymentMoneyPercent;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyChildbirthMoneyPercent() {
        return companyChildbirthMoneyPercent;
    }

    public void setCompanyChildbirthMoneyPercent(BigDecimal companyChildbirthMoneyPercent) {
        this.companyChildbirthMoneyPercent = companyChildbirthMoneyPercent;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public BigDecimal getCompanyInjuryMoneyPercent() {
        return companyInjuryMoneyPercent;
    }

    public void setCompanyInjuryMoneyPercent(BigDecimal companyInjuryMoneyPercent) {
        this.companyInjuryMoneyPercent = companyInjuryMoneyPercent;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
